[svn-commits] trunk - r8299 /trunk/res/res_features.c

svn-commits at lists.digium.com svn-commits at lists.digium.com
Thu Jan 19 15:09:19 MST 2006


Author: oej
Date: Thu Jan 19 16:09:18 2006
New Revision: 8299

URL: http://svn.digium.com/view/asterisk?rev=8299&view=rev
Log:
Doxygen fixes

Modified:
    trunk/res/res_features.c

Modified: trunk/res/res_features.c
URL: http://svn.digium.com/view/asterisk/trunk/res/res_features.c?rev=8299&r1=8298&r2=8299&view=diff
==============================================================================
--- trunk/res/res_features.c (original)
+++ trunk/res/res_features.c Thu Jan 19 16:09:18 2006
@@ -18,7 +18,7 @@
 
 /*! \file
  *
  * \brief Routines implementing call features
  *
  * \author Mark Spencer <markster at digium.com> 
  */
@@ -254,9 +254,9 @@
 	return adsi_print(chan, message, justify, 1);
 }
 
-/*--- ast_park_call: Park a call */
-/* We put the user in the parking list, then wake up the parking thread to be sure it looks
-	   after these channels too */
+/*! \brief Park a call 
+ 	We put the user in the parking list, then wake up the parking thread to be sure it looks
+	after these channels too */
 int ast_park_call(struct ast_channel *chan, struct ast_channel *peer, int timeout, int *extout)
 {
 	struct parkeduser *pu, *cur;
@@ -846,6 +846,7 @@
 
 /* add atxfer and automon as undefined so you can only use em if you configure them */
 #define FEATURES_COUNT (sizeof(builtin_features) / sizeof(builtin_features[0]))
+
 struct ast_call_feature builtin_features[] = 
  {
 	{ AST_FEATURE_REDIRECT, "Blind Transfer", "blindxfer", "#", "#", builtin_blindtransfer, AST_FEATURE_FLAG_NEEDSDTMF },
@@ -857,7 +858,7 @@
 
 static AST_LIST_HEAD(feature_list,ast_call_feature) feature_list;
 
-/* register new feature into feature_list*/
+/*! \brief register new feature into feature_list*/
 void ast_register_feature(struct ast_call_feature *feature)
 {
 	if (!feature) {
@@ -873,7 +874,7 @@
 		ast_verbose(VERBOSE_PREFIX_2 "Registered Feature '%s'\n",feature->sname);
 }
 
-/* unregister feature from feature_list */
+/*! \brief unregister feature from feature_list */
 void ast_unregister_feature(struct ast_call_feature *feature)
 {
 	if (!feature) return;
@@ -894,7 +895,7 @@
 	AST_LIST_UNLOCK(&feature_list);
 }
 
-/* find a feature by name */
+/*! \brief find a feature by name */
 static struct ast_call_feature *find_feature(char *name)
 {
 	struct ast_call_feature *tmp;
@@ -909,7 +910,7 @@
 	return tmp;
 }
 
-/* exec an app by feature */
+/*! \brief exec an app by feature */
 static int feature_exec_app(struct ast_channel *chan, struct ast_channel *peer, struct ast_bridge_config *config, char *code, int sense)
 {
 	struct ast_app *app;
@@ -1888,7 +1889,7 @@
 static struct ast_cli_entry showparked =
 { { "show", "parkedcalls", NULL }, handle_parkedcalls, "Lists parked calls", showparked_help };
 
-/* Dump lot status */
+/*! \brief Dump lot status */
 static int manager_parking_status( struct mansession *s, struct message *m )
 {
 	struct parkeduser *cur;
@@ -18,7 +18,7 @@
 /*! \file
  *
- * \brief Routines implementing call features
+ * \brief Routines implementing call features as call pickup, parking and transfer
  *
  * \author Mark Spencer <markster at digium.com> 



More information about the svn-commits mailing list